# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'createjmain.ui'
#
# Created: Wed Jan  9 10:59:53 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jcreatewin(object):
    def setupUi(self, jcreatewin):
        jcreatewin.setObjectName(_fromUtf8("jcreatewin"))
        jcreatewin.resize(648, 405)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(100)
        sizePolicy.setVerticalStretch(100)
        sizePolicy.setHeightForWidth(jcreatewin.sizePolicy().hasHeightForWidth())
        jcreatewin.setSizePolicy(sizePolicy)
        jcreatewin.setUnifiedTitleAndToolBarOnMac(False)
        self.centralwidget = QtGui.QWidget(jcreatewin)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.joblist = QtGui.QTableWidget(self.centralwidget)
        self.joblist.setGeometry(QtCore.QRect(0, 0, 661, 351))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.joblist.sizePolicy().hasHeightForWidth())
        self.joblist.setSizePolicy(sizePolicy)
        self.joblist.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.joblist.setObjectName(_fromUtf8("joblist"))
        self.joblist.setColumnCount(4)
        self.joblist.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(3, item)
        jcreatewin.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(jcreatewin)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 648, 25))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName(_fromUtf8("menuFile"))
        self.menu_Defaults = QtGui.QMenu(self.menubar)
        self.menu_Defaults.setObjectName(_fromUtf8("menu_Defaults"))
        self.menuJob = QtGui.QMenu(self.menubar)
        self.menuJob.setObjectName(_fromUtf8("menuJob"))
        self.menu_Script = QtGui.QMenu(self.menubar)
        self.menu_Script.setObjectName(_fromUtf8("menu_Script"))
        jcreatewin.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(jcreatewin)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        jcreatewin.setStatusBar(self.statusbar)
        self.action_New_Job = QtGui.QAction(jcreatewin)
        self.action_New_Job.setObjectName(_fromUtf8("action_New_Job"))
        self.action_Open_Job_file = QtGui.QAction(jcreatewin)
        self.action_Open_Job_file.setObjectName(_fromUtf8("action_Open_Job_file"))
        self.action_Save = QtGui.QAction(jcreatewin)
        self.action_Save.setObjectName(_fromUtf8("action_Save"))
        self.actionSave_As = QtGui.QAction(jcreatewin)
        self.actionSave_As.setObjectName(_fromUtf8("actionSave_As"))
        self.action_Close = QtGui.QAction(jcreatewin)
        self.action_Close.setObjectName(_fromUtf8("action_Close"))
        self.action_Quit_back = QtGui.QAction(jcreatewin)
        self.action_Quit_back.setObjectName(_fromUtf8("action_Quit_back"))
        self.action_Time = QtGui.QAction(jcreatewin)
        self.action_Time.setObjectName(_fromUtf8("action_Time"))
        self.action_Conditions = QtGui.QAction(jcreatewin)
        self.action_Conditions.setObjectName(_fromUtf8("action_Conditions"))
        self.action_Assignments = QtGui.QAction(jcreatewin)
        self.action_Assignments.setObjectName(_fromUtf8("action_Assignments"))
        self.actionAr_guments = QtGui.QAction(jcreatewin)
        self.actionAr_guments.setObjectName(_fromUtf8("actionAr_guments"))
        self.action_I_O_Redirections = QtGui.QAction(jcreatewin)
        self.action_I_O_Redirections.setObjectName(_fromUtf8("action_I_O_Redirections"))
        self.action_Process_Parameters = QtGui.QAction(jcreatewin)
        self.action_Process_Parameters.setObjectName(_fromUtf8("action_Process_Parameters"))
        self.actionTitle_Prio_Load_Level = QtGui.QAction(jcreatewin)
        self.actionTitle_Prio_Load_Level.setObjectName(_fromUtf8("actionTitle_Prio_Load_Level"))
        self.action_Environment = QtGui.QAction(jcreatewin)
        self.action_Environment.setObjectName(_fromUtf8("action_Environment"))
        self.action_Process_Parameters_2 = QtGui.QAction(jcreatewin)
        self.action_Process_Parameters_2.setObjectName(_fromUtf8("action_Process_Parameters_2"))
        self.actionTitle_Prio_Load_Level_2 = QtGui.QAction(jcreatewin)
        self.actionTitle_Prio_Load_Level_2.setObjectName(_fromUtf8("actionTitle_Prio_Load_Level_2"))
        self.action_Time_2 = QtGui.QAction(jcreatewin)
        self.action_Time_2.setObjectName(_fromUtf8("action_Time_2"))
        self.action_Conditions_2 = QtGui.QAction(jcreatewin)
        self.action_Conditions_2.setObjectName(_fromUtf8("action_Conditions_2"))
        self.actionAr_guments_2 = QtGui.QAction(jcreatewin)
        self.actionAr_guments_2.setObjectName(_fromUtf8("actionAr_guments_2"))
        self.action_I_O_Redirections_2 = QtGui.QAction(jcreatewin)
        self.action_I_O_Redirections_2.setObjectName(_fromUtf8("action_I_O_Redirections_2"))
        self.action_Environment_2 = QtGui.QAction(jcreatewin)
        self.action_Environment_2.setObjectName(_fromUtf8("action_Environment_2"))
        self.action_Assignments_2 = QtGui.QAction(jcreatewin)
        self.action_Assignments_2.setObjectName(_fromUtf8("action_Assignments_2"))
        self.action_Edit_Script = QtGui.QAction(jcreatewin)
        self.action_Edit_Script.setObjectName(_fromUtf8("action_Edit_Script"))
        self.action_Copy_script = QtGui.QAction(jcreatewin)
        self.action_Copy_script.setObjectName(_fromUtf8("action_Copy_script"))
        self.action_Attach_from_file = QtGui.QAction(jcreatewin)
        self.action_Attach_from_file.setObjectName(_fromUtf8("action_Attach_from_file"))
        self.action_Program_options = QtGui.QAction(jcreatewin)
        self.action_Program_options.setObjectName(_fromUtf8("action_Program_options"))
        self.menuFile.addAction(self.action_New_Job)
        self.menuFile.addAction(self.action_Open_Job_file)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.action_Save)
        self.menuFile.addAction(self.actionSave_As)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.action_Close)
        self.menuFile.addAction(self.action_Program_options)
        self.menuFile.addSeparator()
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.action_Quit_back)
        self.menu_Defaults.addAction(self.actionTitle_Prio_Load_Level)
        self.menu_Defaults.addAction(self.action_Process_Parameters)
        self.menu_Defaults.addSeparator()
        self.menu_Defaults.addAction(self.action_Time)
        self.menu_Defaults.addAction(self.action_Conditions)
        self.menu_Defaults.addAction(self.action_Assignments)
        self.menu_Defaults.addSeparator()
        self.menu_Defaults.addAction(self.actionAr_guments)
        self.menu_Defaults.addAction(self.action_I_O_Redirections)
        self.menu_Defaults.addAction(self.action_Environment)
        self.menuJob.addAction(self.actionTitle_Prio_Load_Level_2)
        self.menuJob.addAction(self.action_Process_Parameters_2)
        self.menuJob.addSeparator()
        self.menuJob.addAction(self.action_Time_2)
        self.menuJob.addAction(self.action_Conditions_2)
        self.menuJob.addAction(self.action_Assignments_2)
        self.menuJob.addSeparator()
        self.menuJob.addAction(self.actionAr_guments_2)
        self.menuJob.addAction(self.action_I_O_Redirections_2)
        self.menuJob.addAction(self.action_Environment_2)
        self.menu_Script.addAction(self.action_Edit_Script)
        self.menu_Script.addAction(self.action_Copy_script)
        self.menu_Script.addAction(self.action_Attach_from_file)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menu_Defaults.menuAction())
        self.menubar.addAction(self.menuJob.menuAction())
        self.menubar.addAction(self.menu_Script.menuAction())

        self.retranslateUi(jcreatewin)
        QtCore.QMetaObject.connectSlotsByName(jcreatewin)

    def retranslateUi(self, jcreatewin):
        jcreatewin.setWindowTitle(QtGui.QApplication.translate("jcreatewin", "Administer job files", None, QtGui.QApplication.UnicodeUTF8))
        jcreatewin.setStatusTip(QtGui.QApplication.translate("jcreatewin", "These are a list of job files ready to save or submit", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(0)
        item.setText(QtGui.QApplication.translate("jcreatewin", "Job file", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(1)
        item.setText(QtGui.QApplication.translate("jcreatewin", "Job title", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(2)
        item.setText(QtGui.QApplication.translate("jcreatewin", "Run/Canc", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(3)
        item.setText(QtGui.QApplication.translate("jcreatewin", "Subm", None, QtGui.QApplication.UnicodeUTF8))
        self.menuFile.setTitle(QtGui.QApplication.translate("jcreatewin", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Defaults.setTitle(QtGui.QApplication.translate("jcreatewin", "&Defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.menuJob.setTitle(QtGui.QApplication.translate("jcreatewin", "Job", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Script.setTitle(QtGui.QApplication.translate("jcreatewin", "&Script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_Job.setText(QtGui.QApplication.translate("jcreatewin", "&New Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Open_Job_file.setText(QtGui.QApplication.translate("jcreatewin", "&Open Job file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save.setText(QtGui.QApplication.translate("jcreatewin", "&Save", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_As.setText(QtGui.QApplication.translate("jcreatewin", "Save &As", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Close.setText(QtGui.QApplication.translate("jcreatewin", "&Close job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Quit_back.setText(QtGui.QApplication.translate("jcreatewin", "&Quit back", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Time.setText(QtGui.QApplication.translate("jcreatewin", "&Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Conditions.setText(QtGui.QApplication.translate("jcreatewin", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assignments.setText(QtGui.QApplication.translate("jcreatewin", "&Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAr_guments.setText(QtGui.QApplication.translate("jcreatewin", "Ar&guments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_I_O_Redirections.setText(QtGui.QApplication.translate("jcreatewin", "&I/O Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Process_Parameters.setText(QtGui.QApplication.translate("jcreatewin", "&Process Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTitle_Prio_Load_Level.setText(QtGui.QApplication.translate("jcreatewin", "Title, Prio, Load Level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment.setText(QtGui.QApplication.translate("jcreatewin", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Process_Parameters_2.setText(QtGui.QApplication.translate("jcreatewin", "&Process Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTitle_Prio_Load_Level_2.setText(QtGui.QApplication.translate("jcreatewin", "Title, Prio, Load Level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Time_2.setText(QtGui.QApplication.translate("jcreatewin", "&Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Conditions_2.setText(QtGui.QApplication.translate("jcreatewin", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAr_guments_2.setText(QtGui.QApplication.translate("jcreatewin", "Ar&guments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_I_O_Redirections_2.setText(QtGui.QApplication.translate("jcreatewin", "&I/O Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment_2.setText(QtGui.QApplication.translate("jcreatewin", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assignments_2.setText(QtGui.QApplication.translate("jcreatewin", "&Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Edit_Script.setText(QtGui.QApplication.translate("jcreatewin", "&Edit Script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Copy_script.setText(QtGui.QApplication.translate("jcreatewin", "&Copy script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Attach_from_file.setText(QtGui.QApplication.translate("jcreatewin", "&Attach from file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Program_options.setText(QtGui.QApplication.translate("jcreatewin", "&Program options", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'btrw_main.ui'
#
# Created: Mon Feb 11 18:23:10 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(800, 600)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/Btrw icon")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setToolTip(_fromUtf8(""))
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.joblist = QtGui.QTableWidget(self.centralwidget)
        self.joblist.setGeometry(QtCore.QRect(0, 10, 791, 491))
        self.joblist.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.joblist.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
        self.joblist.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.joblist.setObjectName(_fromUtf8("joblist"))
        self.joblist.setColumnCount(8)
        self.joblist.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(3, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(4, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(5, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(6, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(7, item)
        self.joblist.horizontalHeader().setVisible(True)
        self.joblist.verticalHeader().setVisible(False)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 25))
        self.menubar.setDefaultUp(False)
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menu_File = QtGui.QMenu(self.menubar)
        self.menu_File.setObjectName(_fromUtf8("menu_File"))
        self.menu_Defaults = QtGui.QMenu(self.menubar)
        self.menu_Defaults.setObjectName(_fromUtf8("menu_Defaults"))
        self.menu_job = QtGui.QMenu(self.menubar)
        self.menu_job.setObjectName(_fromUtf8("menu_job"))
        self.menu_Submission = QtGui.QMenu(self.menubar)
        self.menu_Submission.setObjectName(_fromUtf8("menu_Submission"))
        self.menu_Help = QtGui.QMenu(self.menubar)
        self.menu_Help.setObjectName(_fromUtf8("menu_Help"))
        self.menu_Conditions = QtGui.QMenu(self.menubar)
        self.menu_Conditions.setObjectName(_fromUtf8("menu_Conditions"))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        self.toolBar.setObjectName(_fromUtf8("toolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.action_new_job = QtGui.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/new job file")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_new_job.setIcon(icon1)
        self.action_new_job.setObjectName(_fromUtf8("action_new_job"))
        self.action_open_job = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/open job file")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_open_job.setIcon(icon2)
        self.action_open_job.setObjectName(_fromUtf8("action_open_job"))
        self.action_save = QtGui.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/save job file")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_save.setIcon(icon3)
        self.action_save.setObjectName(_fromUtf8("action_save"))
        self.action_save_as = QtGui.QAction(MainWindow)
        self.action_save_as.setObjectName(_fromUtf8("action_save_as"))
        self.action_close = QtGui.QAction(MainWindow)
        self.action_close.setObjectName(_fromUtf8("action_close"))
        self.action_progopts = QtGui.QAction(MainWindow)
        self.action_progopts.setObjectName(_fromUtf8("action_progopts"))
        self.action_quit = QtGui.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/Quit program")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_quit.setIcon(icon4)
        self.action_quit.setObjectName(_fromUtf8("action_quit"))
        self.action_def_setcanc = QtGui.QAction(MainWindow)
        self.action_def_setcanc.setCheckable(True)
        self.action_def_setcanc.setObjectName(_fromUtf8("action_def_setcanc"))
        self.action_def_titprill = QtGui.QAction(MainWindow)
        self.action_def_titprill.setObjectName(_fromUtf8("action_def_titprill"))
        self.action_def_procpar = QtGui.QAction(MainWindow)
        self.action_def_procpar.setObjectName(_fromUtf8("action_def_procpar"))
        self.action_def_timelim = QtGui.QAction(MainWindow)
        self.action_def_timelim.setObjectName(_fromUtf8("action_def_timelim"))
        self.action_def_perms = QtGui.QAction(MainWindow)
        self.action_def_perms.setObjectName(_fromUtf8("action_def_perms"))
        self.action_def_mailwrite = QtGui.QAction(MainWindow)
        self.action_def_mailwrite.setObjectName(_fromUtf8("action_def_mailwrite"))
        self.action_def_args = QtGui.QAction(MainWindow)
        self.action_def_args.setObjectName(_fromUtf8("action_def_args"))
        self.action_def_redirs = QtGui.QAction(MainWindow)
        self.action_def_redirs.setObjectName(_fromUtf8("action_def_redirs"))
        self.action_job_setrun = QtGui.QAction(MainWindow)
        self.action_job_setrun.setObjectName(_fromUtf8("action_job_setrun"))
        self.action_job_setcanc = QtGui.QAction(MainWindow)
        self.action_job_setcanc.setObjectName(_fromUtf8("action_job_setcanc"))
        self.action_job_titprill = QtGui.QAction(MainWindow)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/Title priority load level")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_titprill.setIcon(icon5)
        self.action_job_titprill.setObjectName(_fromUtf8("action_job_titprill"))
        self.action_job_procpar = QtGui.QAction(MainWindow)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/Process parameters")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_procpar.setIcon(icon6)
        self.action_job_procpar.setObjectName(_fromUtf8("action_job_procpar"))
        self.action_job_timelim = QtGui.QAction(MainWindow)
        self.action_job_timelim.setObjectName(_fromUtf8("action_job_timelim"))
        self.action_job_perms = QtGui.QAction(MainWindow)
        self.action_job_perms.setObjectName(_fromUtf8("action_job_perms"))
        self.action_job_mailwrite = QtGui.QAction(MainWindow)
        self.action_job_mailwrite.setObjectName(_fromUtf8("action_job_mailwrite"))
        self.action_job_args = QtGui.QAction(MainWindow)
        self.action_job_args.setObjectName(_fromUtf8("action_job_args"))
        self.action_job_redirs = QtGui.QAction(MainWindow)
        self.action_job_redirs.setObjectName(_fromUtf8("action_job_redirs"))
        self.action_view_script = QtGui.QAction(MainWindow)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(_fromUtf8(":/View job script")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_view_script.setIcon(icon7)
        self.action_view_script.setObjectName(_fromUtf8("action_view_script"))
        self.action_edit_script = QtGui.QAction(MainWindow)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(_fromUtf8(":/Edit job script")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_edit_script.setIcon(icon8)
        self.action_edit_script.setObjectName(_fromUtf8("action_edit_script"))
        self.action_submit_locally = QtGui.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/Submit job")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_submit_locally.setIcon(icon9)
        self.action_submit_locally.setObjectName(_fromUtf8("action_submit_locally"))
        self.action_submit_remote = QtGui.QAction(MainWindow)
        self.action_submit_remote.setObjectName(_fromUtf8("action_submit_remote"))
        self.action_About_BTRW = QtGui.QAction(MainWindow)
        self.action_About_BTRW.setObjectName(_fromUtf8("action_About_BTRW"))
        self.action_job_conds = QtGui.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/Job conditions")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_conds.setIcon(icon10)
        self.action_job_conds.setObjectName(_fromUtf8("action_job_conds"))
        self.action_job_asses = QtGui.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(_fromUtf8(":/Job assignments")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_asses.setIcon(icon11)
        self.action_job_asses.setObjectName(_fromUtf8("action_job_asses"))
        self.action_def_conds = QtGui.QAction(MainWindow)
        self.action_def_conds.setObjectName(_fromUtf8("action_def_conds"))
        self.action_def_asses = QtGui.QAction(MainWindow)
        self.action_def_asses.setObjectName(_fromUtf8("action_def_asses"))
        self.action_closedel = QtGui.QAction(MainWindow)
        self.action_closedel.setObjectName(_fromUtf8("action_closedel"))
        self.action_saveall = QtGui.QAction(MainWindow)
        self.action_saveall.setObjectName(_fromUtf8("action_saveall"))
        self.action_def_env = QtGui.QAction(MainWindow)
        self.action_def_env.setObjectName(_fromUtf8("action_def_env"))
        self.action_job_env = QtGui.QAction(MainWindow)
        self.action_job_env.setObjectName(_fromUtf8("action_job_env"))
        self.action_job_set_time = QtGui.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/Set time")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_set_time.setIcon(icon12)
        self.action_job_set_time.setObjectName(_fromUtf8("action_job_set_time"))
        self.action_def_set_time = QtGui.QAction(MainWindow)
        self.action_def_set_time.setObjectName(_fromUtf8("action_def_set_time"))
        self.menu_File.addAction(self.action_new_job)
        self.menu_File.addAction(self.action_open_job)
        self.menu_File.addAction(self.action_save)
        self.menu_File.addAction(self.action_save_as)
        self.menu_File.addAction(self.action_saveall)
        self.menu_File.addAction(self.action_close)
        self.menu_File.addAction(self.action_closedel)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_progopts)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_quit)
        self.menu_Defaults.addAction(self.action_def_setcanc)
        self.menu_Defaults.addSeparator()
        self.menu_Defaults.addAction(self.action_def_set_time)
        self.menu_Defaults.addAction(self.action_def_titprill)
        self.menu_Defaults.addAction(self.action_def_procpar)
        self.menu_Defaults.addAction(self.action_def_timelim)
        self.menu_Defaults.addAction(self.action_def_perms)
        self.menu_Defaults.addAction(self.action_def_mailwrite)
        self.menu_Defaults.addSeparator()
        self.menu_Defaults.addAction(self.action_def_args)
        self.menu_Defaults.addAction(self.action_def_redirs)
        self.menu_Defaults.addAction(self.action_def_env)
        self.menu_job.addAction(self.action_job_setrun)
        self.menu_job.addAction(self.action_job_setcanc)
        self.menu_job.addSeparator()
        self.menu_job.addAction(self.action_job_set_time)
        self.menu_job.addAction(self.action_job_titprill)
        self.menu_job.addAction(self.action_job_procpar)
        self.menu_job.addAction(self.action_job_timelim)
        self.menu_job.addAction(self.action_job_perms)
        self.menu_job.addAction(self.action_job_mailwrite)
        self.menu_job.addSeparator()
        self.menu_job.addAction(self.action_job_args)
        self.menu_job.addAction(self.action_job_redirs)
        self.menu_job.addAction(self.action_job_env)
        self.menu_Submission.addAction(self.action_view_script)
        self.menu_Submission.addAction(self.action_edit_script)
        self.menu_Submission.addSeparator()
        self.menu_Submission.addAction(self.action_submit_locally)
        self.menu_Submission.addAction(self.action_submit_remote)
        self.menu_Help.addAction(self.action_About_BTRW)
        self.menu_Conditions.addAction(self.action_job_conds)
        self.menu_Conditions.addAction(self.action_job_asses)
        self.menu_Conditions.addSeparator()
        self.menu_Conditions.addAction(self.action_def_conds)
        self.menu_Conditions.addAction(self.action_def_asses)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Defaults.menuAction())
        self.menubar.addAction(self.menu_job.menuAction())
        self.menubar.addAction(self.menu_Conditions.menuAction())
        self.menubar.addAction(self.menu_Submission.menuAction())
        self.menubar.addAction(self.menu_Help.menuAction())
        self.toolBar.addAction(self.action_new_job)
        self.toolBar.addAction(self.action_open_job)
        self.toolBar.addAction(self.action_save)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_view_script)
        self.toolBar.addAction(self.action_edit_script)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_submit_locally)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_job_set_time)
        self.toolBar.addAction(self.action_job_titprill)
        self.toolBar.addAction(self.action_job_procpar)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_job_conds)
        self.toolBar.addAction(self.action_job_asses)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Administer saved job files", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(0)
        item.setText(QtGui.QApplication.translate("MainWindow", "Directory", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(1)
        item.setText(QtGui.QApplication.translate("MainWindow", "File", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(2)
        item.setText(QtGui.QApplication.translate("MainWindow", "Title", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(3)
        item.setText(QtGui.QApplication.translate("MainWindow", "CI", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(4)
        item.setText(QtGui.QApplication.translate("MainWindow", "Scr", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(5)
        item.setText(QtGui.QApplication.translate("MainWindow", "R/C", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(6)
        item.setText(QtGui.QApplication.translate("MainWindow", "Subm", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(7)
        item.setText(QtGui.QApplication.translate("MainWindow", "Ch", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_File.setTitle(QtGui.QApplication.translate("MainWindow", "&File", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Defaults.setTitle(QtGui.QApplication.translate("MainWindow", "&Defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_job.setTitle(QtGui.QApplication.translate("MainWindow", "&job", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Submission.setTitle(QtGui.QApplication.translate("MainWindow", "&Submission", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Help.setTitle(QtGui.QApplication.translate("MainWindow", "&Help", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Conditions.setTitle(QtGui.QApplication.translate("MainWindow", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.toolBar.setWindowTitle(QtGui.QApplication.translate("MainWindow", "toolBar", None, QtGui.QApplication.UnicodeUTF8))
        self.action_new_job.setText(QtGui.QApplication.translate("MainWindow", "&New job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_new_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Create a new job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_new_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+N", None, QtGui.QApplication.UnicodeUTF8))
        self.action_open_job.setText(QtGui.QApplication.translate("MainWindow", "&Open job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_open_job.setToolTip(QtGui.QApplication.translate("MainWindow", "open an existing job file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_open_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+O", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save.setText(QtGui.QApplication.translate("MainWindow", "&Save", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save.setToolTip(QtGui.QApplication.translate("MainWindow", "save job to file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+S", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save_as.setText(QtGui.QApplication.translate("MainWindow", "Save &as", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save_as.setToolTip(QtGui.QApplication.translate("MainWindow", "save job to prompted-for file name", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save_as.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+S", None, QtGui.QApplication.UnicodeUTF8))
        self.action_close.setText(QtGui.QApplication.translate("MainWindow", "&Close", None, QtGui.QApplication.UnicodeUTF8))
        self.action_close.setToolTip(QtGui.QApplication.translate("MainWindow", "close job file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_close.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+W", None, QtGui.QApplication.UnicodeUTF8))
        self.action_progopts.setText(QtGui.QApplication.translate("MainWindow", "&Program options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit.setText(QtGui.QApplication.translate("MainWindow", "&Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit.setToolTip(QtGui.QApplication.translate("MainWindow", "Quit program", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Q", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_setcanc.setText(QtGui.QApplication.translate("MainWindow", "Set &Cancelled", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_setcanc.setToolTip(QtGui.QApplication.translate("MainWindow", "Select this if you want new jobs to be set by default to the cancelled state\n"
"", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_titprill.setText(QtGui.QApplication.translate("MainWindow", "&Title priority load level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_titprill.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default title, priority, load level and command interpreter", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_procpar.setText(QtGui.QApplication.translate("MainWindow", "&Process parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_procpar.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default values for process parameters such as working directory,\n"
"umask, exit code ranges", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_timelim.setText(QtGui.QApplication.translate("MainWindow", "&Time limits", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_timelim.setToolTip(QtGui.QApplication.translate("MainWindow", "Set various default time limits", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_perms.setText(QtGui.QApplication.translate("MainWindow", "Per&missions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_perms.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_mailwrite.setText(QtGui.QApplication.translate("MainWindow", "&Mail / write", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_mailwrite.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default mail and write message options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_args.setText(QtGui.QApplication.translate("MainWindow", "Ar&guments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_args.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default job arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_redirs.setText(QtGui.QApplication.translate("MainWindow", "&Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_redirs.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default job redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_setrun.setText(QtGui.QApplication.translate("MainWindow", "Set &runnable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_setrun.setShortcut(QtGui.QApplication.translate("MainWindow", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_setcanc.setText(QtGui.QApplication.translate("MainWindow", "Set &cancelled", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_setcanc.setShortcut(QtGui.QApplication.translate("MainWindow", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_titprill.setText(QtGui.QApplication.translate("MainWindow", "&Title, priority, load level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_titprill.setToolTip(QtGui.QApplication.translate("MainWindow", "Title, priority, load level, command interpreter", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_titprill.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+T", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_procpar.setText(QtGui.QApplication.translate("MainWindow", "&Process parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_procpar.setToolTip(QtGui.QApplication.translate("MainWindow", "Process parameters (directory, umask, ulimit) for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_procpar.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+P", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_timelim.setText(QtGui.QApplication.translate("MainWindow", "Time &limits", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_timelim.setToolTip(QtGui.QApplication.translate("MainWindow", "Time limits for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_perms.setText(QtGui.QApplication.translate("MainWindow", "Per&missions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_perms.setToolTip(QtGui.QApplication.translate("MainWindow", "Permissions on the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_mailwrite.setText(QtGui.QApplication.translate("MainWindow", "&Mail / Write", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_mailwrite.setToolTip(QtGui.QApplication.translate("MainWindow", "Mail / Write flag settings", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_args.setText(QtGui.QApplication.translate("MainWindow", "&Arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_args.setToolTip(QtGui.QApplication.translate("MainWindow", "Edit the job arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_redirs.setText(QtGui.QApplication.translate("MainWindow", "&Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_redirs.setToolTip(QtGui.QApplication.translate("MainWindow", "Edit the job redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_view_script.setText(QtGui.QApplication.translate("MainWindow", "&View script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_view_script.setToolTip(QtGui.QApplication.translate("MainWindow", "View the script of the job (read-only)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_edit_script.setText(QtGui.QApplication.translate("MainWindow", "&Edit script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_edit_script.setToolTip(QtGui.QApplication.translate("MainWindow", "Edit script of job in selected editor", None, QtGui.QApplication.UnicodeUTF8))
        self.action_submit_locally.setText(QtGui.QApplication.translate("MainWindow", "&Submit locally", None, QtGui.QApplication.UnicodeUTF8))
        self.action_submit_locally.setToolTip(QtGui.QApplication.translate("MainWindow", "Submit job to local/standard server", None, QtGui.QApplication.UnicodeUTF8))
        self.action_submit_remote.setText(QtGui.QApplication.translate("MainWindow", "&Submit remote", None, QtGui.QApplication.UnicodeUTF8))
        self.action_submit_remote.setToolTip(QtGui.QApplication.translate("MainWindow", "Submit job to alternative server", None, QtGui.QApplication.UnicodeUTF8))
        self.action_About_BTRW.setText(QtGui.QApplication.translate("MainWindow", "&About BTRW", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_conds.setText(QtGui.QApplication.translate("MainWindow", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_conds.setToolTip(QtGui.QApplication.translate("MainWindow", "Set conditions on the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_asses.setText(QtGui.QApplication.translate("MainWindow", "&Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_asses.setToolTip(QtGui.QApplication.translate("MainWindow", "Set assignments on the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_conds.setText(QtGui.QApplication.translate("MainWindow", "&Default conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_conds.setToolTip(QtGui.QApplication.translate("MainWindow", "Set default conditions for new jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_asses.setText(QtGui.QApplication.translate("MainWindow", "D&efault assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_asses.setToolTip(QtGui.QApplication.translate("MainWindow", "Set default assignments for new jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_closedel.setText(QtGui.QApplication.translate("MainWindow", "Close and &Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.action_closedel.setToolTip(QtGui.QApplication.translate("MainWindow", "This closes the job file and additionally deletes it.", None, QtGui.QApplication.UnicodeUTF8))
        self.action_saveall.setText(QtGui.QApplication.translate("MainWindow", "Save A&ll", None, QtGui.QApplication.UnicodeUTF8))
        self.action_saveall.setToolTip(QtGui.QApplication.translate("MainWindow", "Save all unsaved jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_env.setText(QtGui.QApplication.translate("MainWindow", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_env.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default list of environment variables for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_env.setText(QtGui.QApplication.translate("MainWindow", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_env.setToolTip(QtGui.QApplication.translate("MainWindow", "Edit the list of environment variables for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_env.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+E", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_set_time.setText(QtGui.QApplication.translate("MainWindow", "&Set time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_set_time.setToolTip(QtGui.QApplication.translate("MainWindow", "Set time and repeat parameters for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_set_time.setShortcut(QtGui.QApplication.translate("MainWindow", "T", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_set_time.setText(QtGui.QApplication.translate("MainWindow", "&Set time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_set_time.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default time and repeat parameters", None, QtGui.QApplication.UnicodeUTF8))

import resources_rc



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'login.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_logindlg(object):
    def setupUi(self, logindlg):
        logindlg.setObjectName(_fromUtf8("logindlg"))
        logindlg.resize(400, 300)
        self.buttonBox = QtGui.QDialogButtonBox(logindlg)
        self.buttonBox.setGeometry(QtCore.QRect(30, 240, 341, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.layoutWidget = QtGui.QWidget(logindlg)
        self.layoutWidget.setGeometry(QtCore.QRect(60, 20, 258, 191))
        self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
        self.gridLayout = QtGui.QGridLayout(self.layoutWidget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.label = QtGui.QLabel(self.layoutWidget)
        self.label.setObjectName(_fromUtf8("label"))
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.servName = QtGui.QLineEdit(self.layoutWidget)
        self.servName.setReadOnly(True)
        self.servName.setObjectName(_fromUtf8("servName"))
        self.gridLayout.addWidget(self.servName, 0, 1, 1, 1)
        self.label_2 = QtGui.QLabel(self.layoutWidget)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.clientName = QtGui.QLineEdit(self.layoutWidget)
        self.clientName.setReadOnly(True)
        self.clientName.setObjectName(_fromUtf8("clientName"))
        self.gridLayout.addWidget(self.clientName, 1, 1, 1, 1)
        self.label_3 = QtGui.QLabel(self.layoutWidget)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.userName = QtGui.QLineEdit(self.layoutWidget)
        self.userName.setObjectName(_fromUtf8("userName"))
        self.gridLayout.addWidget(self.userName, 2, 1, 1, 1)
        self.label_4 = QtGui.QLabel(self.layoutWidget)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.gridLayout.addWidget(self.label_4, 3, 0, 1, 1)
        self.password = QtGui.QLineEdit(self.layoutWidget)
        self.password.setEchoMode(QtGui.QLineEdit.Password)
        self.password.setObjectName(_fromUtf8("password"))
        self.gridLayout.addWidget(self.password, 3, 1, 1, 1)
        self.label.setBuddy(self.servName)
        self.label_2.setBuddy(self.clientName)
        self.label_3.setBuddy(self.userName)
        self.label_4.setBuddy(self.password)

        self.retranslateUi(logindlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), logindlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), logindlg.reject)
        QtCore.QMetaObject.connectSlotsByName(logindlg)
        logindlg.setTabOrder(self.servName, self.clientName)
        logindlg.setTabOrder(self.clientName, self.userName)
        logindlg.setTabOrder(self.userName, self.password)
        logindlg.setTabOrder(self.password, self.buttonBox)

    def retranslateUi(self, logindlg):
        logindlg.setWindowTitle(QtGui.QApplication.translate("logindlg", "Login as user", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("logindlg", "Log in to server", None, QtGui.QApplication.UnicodeUTF8))
        self.servName.setToolTip(QtGui.QApplication.translate("logindlg", "This is the server being logged in to (don\'t set it here)", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("logindlg", "This client name", None, QtGui.QApplication.UnicodeUTF8))
        self.clientName.setToolTip(QtGui.QApplication.translate("logindlg", "This is the name of this machine", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("logindlg", "&User name", None, QtGui.QApplication.UnicodeUTF8))
        self.userName.setToolTip(QtGui.QApplication.translate("logindlg", "User name to log in as", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("logindlg", "&Password", None, QtGui.QApplication.UnicodeUTF8))
        self.password.setToolTip(QtGui.QApplication.translate("logindlg", "Password (if required)", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'upermdisp.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_userperms(object):
    def setupUi(self, userperms):
        userperms.setObjectName(_fromUtf8("userperms"))
        userperms.resize(672, 834)
        self.buttonBox = QtGui.QDialogButtonBox(userperms)
        self.buttonBox.setGeometry(QtCore.QRect(490, 780, 111, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(userperms)
        self.label.setGeometry(QtCore.QRect(30, 30, 191, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.servname = QtGui.QLineEdit(userperms)
        self.servname.setGeometry(QtCore.QRect(220, 20, 321, 27))
        self.servname.setFrame(False)
        self.servname.setReadOnly(True)
        self.servname.setObjectName(_fromUtf8("servname"))
        self.label_2 = QtGui.QLabel(userperms)
        self.label_2.setGeometry(QtCore.QRect(30, 60, 101, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.username = QtGui.QLineEdit(userperms)
        self.username.setGeometry(QtCore.QRect(220, 50, 231, 27))
        self.username.setFrame(False)
        self.username.setReadOnly(True)
        self.username.setObjectName(_fromUtf8("username"))
        self.radminperm = QtGui.QCheckBox(userperms)
        self.radminperm.setGeometry(QtCore.QRect(30, 240, 151, 22))
        self.radminperm.setObjectName(_fromUtf8("radminperm"))
        self.wadminperm = QtGui.QCheckBox(userperms)
        self.wadminperm.setGeometry(QtCore.QRect(30, 270, 171, 22))
        self.wadminperm.setObjectName(_fromUtf8("wadminperm"))
        self.createperm = QtGui.QCheckBox(userperms)
        self.createperm.setGeometry(QtCore.QRect(30, 300, 141, 22))
        self.createperm.setObjectName(_fromUtf8("createperm"))
        self.chpermperm = QtGui.QCheckBox(userperms)
        self.chpermperm.setGeometry(QtCore.QRect(30, 330, 311, 22))
        self.chpermperm.setObjectName(_fromUtf8("chpermperm"))
        self.spcreateperm = QtGui.QCheckBox(userperms)
        self.spcreateperm.setGeometry(QtCore.QRect(30, 360, 161, 22))
        self.spcreateperm.setObjectName(_fromUtf8("spcreateperm"))
        self.or_ug_perm = QtGui.QCheckBox(userperms)
        self.or_ug_perm.setGeometry(QtCore.QRect(290, 240, 181, 22))
        self.or_ug_perm.setObjectName(_fromUtf8("or_ug_perm"))
        self.or_uo_perm = QtGui.QCheckBox(userperms)
        self.or_uo_perm.setGeometry(QtCore.QRect(290, 270, 191, 22))
        self.or_uo_perm.setObjectName(_fromUtf8("or_uo_perm"))
        self.or_go_perm = QtGui.QCheckBox(userperms)
        self.or_go_perm.setGeometry(QtCore.QRect(290, 300, 191, 22))
        self.or_go_perm.setObjectName(_fromUtf8("or_go_perm"))
        self.sstopperm = QtGui.QCheckBox(userperms)
        self.sstopperm.setGeometry(QtCore.QRect(290, 330, 181, 22))
        self.sstopperm.setObjectName(_fromUtf8("sstopperm"))
        self.label_3 = QtGui.QLabel(userperms)
        self.label_3.setGeometry(QtCore.QRect(30, 130, 62, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(userperms)
        self.label_4.setGeometry(QtCore.QRect(30, 160, 62, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(userperms)
        self.label_5.setGeometry(QtCore.QRect(30, 190, 62, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.minpri = QtGui.QLineEdit(userperms)
        self.minpri.setGeometry(QtCore.QRect(90, 120, 81, 27))
        self.minpri.setFrame(False)
        self.minpri.setReadOnly(True)
        self.minpri.setObjectName(_fromUtf8("minpri"))
        self.defpri = QtGui.QLineEdit(userperms)
        self.defpri.setGeometry(QtCore.QRect(90, 150, 81, 27))
        self.defpri.setFrame(False)
        self.defpri.setReadOnly(True)
        self.defpri.setObjectName(_fromUtf8("defpri"))
        self.maxpri = QtGui.QLineEdit(userperms)
        self.maxpri.setGeometry(QtCore.QRect(90, 180, 81, 27))
        self.maxpri.setFrame(False)
        self.maxpri.setReadOnly(True)
        self.maxpri.setObjectName(_fromUtf8("maxpri"))
        self.label_6 = QtGui.QLabel(userperms)
        self.label_6.setGeometry(QtCore.QRect(30, 90, 101, 17))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.groupname = QtGui.QLineEdit(userperms)
        self.groupname.setGeometry(QtCore.QRect(220, 80, 231, 27))
        self.groupname.setFrame(False)
        self.groupname.setReadOnly(True)
        self.groupname.setObjectName(_fromUtf8("groupname"))
        self.label_7 = QtGui.QLabel(userperms)
        self.label_7.setGeometry(QtCore.QRect(220, 190, 62, 17))
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.totll = QtGui.QLineEdit(userperms)
        self.totll.setGeometry(QtCore.QRect(300, 150, 81, 27))
        self.totll.setToolTip(_fromUtf8("This is the total load level for jobs running at once"))
        self.totll.setFrame(False)
        self.totll.setReadOnly(True)
        self.totll.setObjectName(_fromUtf8("totll"))
        self.label_8 = QtGui.QLabel(userperms)
        self.label_8.setGeometry(QtCore.QRect(220, 160, 62, 17))
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.maxll = QtGui.QLineEdit(userperms)
        self.maxll.setGeometry(QtCore.QRect(300, 120, 81, 27))
        self.maxll.setFrame(False)
        self.maxll.setReadOnly(True)
        self.maxll.setObjectName(_fromUtf8("maxll"))
        self.label_9 = QtGui.QLabel(userperms)
        self.label_9.setGeometry(QtCore.QRect(220, 130, 62, 17))
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.speccll = QtGui.QLineEdit(userperms)
        self.speccll.setGeometry(QtCore.QRect(300, 180, 81, 27))
        self.speccll.setFrame(False)
        self.speccll.setReadOnly(True)
        self.speccll.setObjectName(_fromUtf8("speccll"))
        self.label_10 = QtGui.QLabel(userperms)
        self.label_10.setGeometry(QtCore.QRect(210, 370, 161, 20))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_10.setFont(font)
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.permtab = QtGui.QTabWidget(userperms)
        self.permtab.setGeometry(QtCore.QRect(60, 410, 471, 356))
        self.permtab.setObjectName(_fromUtf8("permtab"))
        self.juser = QtGui.QWidget()
        self.juser.setObjectName(_fromUtf8("juser"))
        self.horizontalLayout_5 = QtGui.QHBoxLayout(self.juser)
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.gridLayout = QtGui.QGridLayout()
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.ju_read = QtGui.QCheckBox(self.juser)
        self.ju_read.setObjectName(_fromUtf8("ju_read"))
        self.gridLayout.addWidget(self.ju_read, 0, 0, 1, 1)
        self.ju_write = QtGui.QCheckBox(self.juser)
        self.ju_write.setObjectName(_fromUtf8("ju_write"))
        self.gridLayout.addWidget(self.ju_write, 1, 0, 1, 1)
        self.ju_show = QtGui.QCheckBox(self.juser)
        self.ju_show.setObjectName(_fromUtf8("ju_show"))
        self.gridLayout.addWidget(self.ju_show, 2, 0, 1, 1)
        self.ju_rperm = QtGui.QCheckBox(self.juser)
        self.ju_rperm.setObjectName(_fromUtf8("ju_rperm"))
        self.gridLayout.addWidget(self.ju_rperm, 3, 0, 1, 1)
        self.ju_wperm = QtGui.QCheckBox(self.juser)
        self.ju_wperm.setObjectName(_fromUtf8("ju_wperm"))
        self.gridLayout.addWidget(self.ju_wperm, 4, 0, 1, 1)
        self.ju_utake = QtGui.QCheckBox(self.juser)
        self.ju_utake.setObjectName(_fromUtf8("ju_utake"))
        self.gridLayout.addWidget(self.ju_utake, 5, 0, 1, 1)
        self.ju_gtake = QtGui.QCheckBox(self.juser)
        self.ju_gtake.setObjectName(_fromUtf8("ju_gtake"))
        self.gridLayout.addWidget(self.ju_gtake, 6, 0, 1, 1)
        self.ju_ugive = QtGui.QCheckBox(self.juser)
        self.ju_ugive.setObjectName(_fromUtf8("ju_ugive"))
        self.gridLayout.addWidget(self.ju_ugive, 7, 0, 1, 1)
        self.ju_del = QtGui.QCheckBox(self.juser)
        self.ju_del.setObjectName(_fromUtf8("ju_del"))
        self.gridLayout.addWidget(self.ju_del, 9, 0, 1, 1)
        self.ju_kill = QtGui.QCheckBox(self.juser)
        self.ju_kill.setObjectName(_fromUtf8("ju_kill"))
        self.gridLayout.addWidget(self.ju_kill, 10, 0, 1, 1)
        self.ju_ggive = QtGui.QCheckBox(self.juser)
        self.ju_ggive.setObjectName(_fromUtf8("ju_ggive"))
        self.gridLayout.addWidget(self.ju_ggive, 8, 0, 1, 1)
        self.horizontalLayout_5.addLayout(self.gridLayout)
        self.permtab.addTab(self.juser, _fromUtf8(""))
        self.jgroup = QtGui.QWidget()
        self.jgroup.setObjectName(_fromUtf8("jgroup"))
        self.horizontalLayout_4 = QtGui.QHBoxLayout(self.jgroup)
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.gridLayout_2 = QtGui.QGridLayout()
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.jg_read = QtGui.QCheckBox(self.jgroup)
        self.jg_read.setObjectName(_fromUtf8("jg_read"))
        self.gridLayout_2.addWidget(self.jg_read, 0, 0, 1, 1)
        self.jg_write = QtGui.QCheckBox(self.jgroup)
        self.jg_write.setObjectName(_fromUtf8("jg_write"))
        self.gridLayout_2.addWidget(self.jg_write, 1, 0, 1, 1)
        self.jg_show = QtGui.QCheckBox(self.jgroup)
        self.jg_show.setObjectName(_fromUtf8("jg_show"))
        self.gridLayout_2.addWidget(self.jg_show, 2, 0, 1, 1)
        self.jg_rperm = QtGui.QCheckBox(self.jgroup)
        self.jg_rperm.setObjectName(_fromUtf8("jg_rperm"))
        self.gridLayout_2.addWidget(self.jg_rperm, 3, 0, 1, 1)
        self.jg_wperm = QtGui.QCheckBox(self.jgroup)
        self.jg_wperm.setObjectName(_fromUtf8("jg_wperm"))
        self.gridLayout_2.addWidget(self.jg_wperm, 4, 0, 1, 1)
        self.jg_utake = QtGui.QCheckBox(self.jgroup)
        self.jg_utake.setObjectName(_fromUtf8("jg_utake"))
        self.gridLayout_2.addWidget(self.jg_utake, 5, 0, 1, 1)
        self.jg_gtake = QtGui.QCheckBox(self.jgroup)
        self.jg_gtake.setObjectName(_fromUtf8("jg_gtake"))
        self.gridLayout_2.addWidget(self.jg_gtake, 6, 0, 1, 1)
        self.jg_ugive = QtGui.QCheckBox(self.jgroup)
        self.jg_ugive.setObjectName(_fromUtf8("jg_ugive"))
        self.gridLayout_2.addWidget(self.jg_ugive, 7, 0, 1, 1)
        self.jg_del = QtGui.QCheckBox(self.jgroup)
        self.jg_del.setObjectName(_fromUtf8("jg_del"))
        self.gridLayout_2.addWidget(self.jg_del, 9, 0, 1, 1)
        self.jg_kill = QtGui.QCheckBox(self.jgroup)
        self.jg_kill.setObjectName(_fromUtf8("jg_kill"))
        self.gridLayout_2.addWidget(self.jg_kill, 10, 0, 1, 1)
        self.jg_ggive = QtGui.QCheckBox(self.jgroup)
        self.jg_ggive.setObjectName(_fromUtf8("jg_ggive"))
        self.gridLayout_2.addWidget(self.jg_ggive, 8, 0, 1, 1)
        self.horizontalLayout_4.addLayout(self.gridLayout_2)
        self.permtab.addTab(self.jgroup, _fromUtf8(""))
        self.jother = QtGui.QWidget()
        self.jother.setObjectName(_fromUtf8("jother"))
        self.horizontalLayout_3 = QtGui.QHBoxLayout(self.jother)
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.gridLayout_3 = QtGui.QGridLayout()
        self.gridLayout_3.setObjectName(_fromUtf8("gridLayout_3"))
        self.jo_read = QtGui.QCheckBox(self.jother)
        self.jo_read.setObjectName(_fromUtf8("jo_read"))
        self.gridLayout_3.addWidget(self.jo_read, 0, 0, 1, 1)
        self.jo_write = QtGui.QCheckBox(self.jother)
        self.jo_write.setObjectName(_fromUtf8("jo_write"))
        self.gridLayout_3.addWidget(self.jo_write, 1, 0, 1, 1)
        self.jo_show = QtGui.QCheckBox(self.jother)
        self.jo_show.setObjectName(_fromUtf8("jo_show"))
        self.gridLayout_3.addWidget(self.jo_show, 2, 0, 1, 1)
        self.jo_rperm = QtGui.QCheckBox(self.jother)
        self.jo_rperm.setObjectName(_fromUtf8("jo_rperm"))
        self.gridLayout_3.addWidget(self.jo_rperm, 3, 0, 1, 1)
        self.jo_wperm = QtGui.QCheckBox(self.jother)
        self.jo_wperm.setObjectName(_fromUtf8("jo_wperm"))
        self.gridLayout_3.addWidget(self.jo_wperm, 4, 0, 1, 1)
        self.jo_utake = QtGui.QCheckBox(self.jother)
        self.jo_utake.setObjectName(_fromUtf8("jo_utake"))
        self.gridLayout_3.addWidget(self.jo_utake, 5, 0, 1, 1)
        self.jo_gtake = QtGui.QCheckBox(self.jother)
        self.jo_gtake.setObjectName(_fromUtf8("jo_gtake"))
        self.gridLayout_3.addWidget(self.jo_gtake, 6, 0, 1, 1)
        self.jo_ugive = QtGui.QCheckBox(self.jother)
        self.jo_ugive.setObjectName(_fromUtf8("jo_ugive"))
        self.gridLayout_3.addWidget(self.jo_ugive, 7, 0, 1, 1)
        self.jo_del = QtGui.QCheckBox(self.jother)
        self.jo_del.setObjectName(_fromUtf8("jo_del"))
        self.gridLayout_3.addWidget(self.jo_del, 9, 0, 1, 1)
        self.jo_kill = QtGui.QCheckBox(self.jother)
        self.jo_kill.setObjectName(_fromUtf8("jo_kill"))
        self.gridLayout_3.addWidget(self.jo_kill, 10, 0, 1, 1)
        self.jo_ggive = QtGui.QCheckBox(self.jother)
        self.jo_ggive.setObjectName(_fromUtf8("jo_ggive"))
        self.gridLayout_3.addWidget(self.jo_ggive, 8, 0, 1, 1)
        self.horizontalLayout_3.addLayout(self.gridLayout_3)
        self.permtab.addTab(self.jother, _fromUtf8(""))
        self.vuser = QtGui.QWidget()
        self.vuser.setObjectName(_fromUtf8("vuser"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.vuser)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.gridLayout_4 = QtGui.QGridLayout()
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        self.vu_read = QtGui.QCheckBox(self.vuser)
        self.vu_read.setObjectName(_fromUtf8("vu_read"))
        self.gridLayout_4.addWidget(self.vu_read, 0, 0, 1, 1)
        self.vu_write = QtGui.QCheckBox(self.vuser)
        self.vu_write.setObjectName(_fromUtf8("vu_write"))
        self.gridLayout_4.addWidget(self.vu_write, 1, 0, 1, 1)
        self.vu_show = QtGui.QCheckBox(self.vuser)
        self.vu_show.setObjectName(_fromUtf8("vu_show"))
        self.gridLayout_4.addWidget(self.vu_show, 2, 0, 1, 1)
        self.vu_rperm = QtGui.QCheckBox(self.vuser)
        self.vu_rperm.setObjectName(_fromUtf8("vu_rperm"))
        self.gridLayout_4.addWidget(self.vu_rperm, 3, 0, 1, 1)
        self.vu_wperm = QtGui.QCheckBox(self.vuser)
        self.vu_wperm.setObjectName(_fromUtf8("vu_wperm"))
        self.gridLayout_4.addWidget(self.vu_wperm, 4, 0, 1, 1)
        self.vu_utake = QtGui.QCheckBox(self.vuser)
        self.vu_utake.setObjectName(_fromUtf8("vu_utake"))
        self.gridLayout_4.addWidget(self.vu_utake, 5, 0, 1, 1)
        self.vu_gtake = QtGui.QCheckBox(self.vuser)
        self.vu_gtake.setObjectName(_fromUtf8("vu_gtake"))
        self.gridLayout_4.addWidget(self.vu_gtake, 6, 0, 1, 1)
        self.vu_ugive = QtGui.QCheckBox(self.vuser)
        self.vu_ugive.setObjectName(_fromUtf8("vu_ugive"))
        self.gridLayout_4.addWidget(self.vu_ugive, 7, 0, 1, 1)
        self.vu_del = QtGui.QCheckBox(self.vuser)
        self.vu_del.setObjectName(_fromUtf8("vu_del"))
        self.gridLayout_4.addWidget(self.vu_del, 9, 0, 1, 1)
        self.vu_ggive = QtGui.QCheckBox(self.vuser)
        self.vu_ggive.setObjectName(_fromUtf8("vu_ggive"))
        self.gridLayout_4.addWidget(self.vu_ggive, 8, 0, 1, 1)
        self.horizontalLayout_2.addLayout(self.gridLayout_4)
        self.permtab.addTab(self.vuser, _fromUtf8(""))
        self.vgroup = QtGui.QWidget()
        self.vgroup.setObjectName(_fromUtf8("vgroup"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.vgroup)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.gridLayout_5 = QtGui.QGridLayout()
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.vg_read = QtGui.QCheckBox(self.vgroup)
        self.vg_read.setObjectName(_fromUtf8("vg_read"))
        self.gridLayout_5.addWidget(self.vg_read, 0, 0, 1, 1)
        self.vg_write = QtGui.QCheckBox(self.vgroup)
        self.vg_write.setObjectName(_fromUtf8("vg_write"))
        self.gridLayout_5.addWidget(self.vg_write, 1, 0, 1, 1)
        self.vg_show = QtGui.QCheckBox(self.vgroup)
        self.vg_show.setObjectName(_fromUtf8("vg_show"))
        self.gridLayout_5.addWidget(self.vg_show, 2, 0, 1, 1)
        self.vg_rperm = QtGui.QCheckBox(self.vgroup)
        self.vg_rperm.setObjectName(_fromUtf8("vg_rperm"))
        self.gridLayout_5.addWidget(self.vg_rperm, 3, 0, 1, 1)
        self.vg_wperm = QtGui.QCheckBox(self.vgroup)
        self.vg_wperm.setObjectName(_fromUtf8("vg_wperm"))
        self.gridLayout_5.addWidget(self.vg_wperm, 4, 0, 1, 1)
        self.vg_utake = QtGui.QCheckBox(self.vgroup)
        self.vg_utake.setObjectName(_fromUtf8("vg_utake"))
        self.gridLayout_5.addWidget(self.vg_utake, 5, 0, 1, 1)
        self.vg_gtake = QtGui.QCheckBox(self.vgroup)
        self.vg_gtake.setObjectName(_fromUtf8("vg_gtake"))
        self.gridLayout_5.addWidget(self.vg_gtake, 6, 0, 1, 1)
        self.vg_ugive = QtGui.QCheckBox(self.vgroup)
        self.vg_ugive.setObjectName(_fromUtf8("vg_ugive"))
        self.gridLayout_5.addWidget(self.vg_ugive, 7, 0, 1, 1)
        self.vg_ggive = QtGui.QCheckBox(self.vgroup)
        self.vg_ggive.setObjectName(_fromUtf8("vg_ggive"))
        self.gridLayout_5.addWidget(self.vg_ggive, 8, 0, 1, 1)
        self.vg_del = QtGui.QCheckBox(self.vgroup)
        self.vg_del.setObjectName(_fromUtf8("vg_del"))
        self.gridLayout_5.addWidget(self.vg_del, 9, 0, 1, 1)
        self.horizontalLayout.addLayout(self.gridLayout_5)
        self.permtab.addTab(self.vgroup, _fromUtf8(""))
        self.vother = QtGui.QWidget()
        self.vother.setObjectName(_fromUtf8("vother"))
        self.hboxlayout = QtGui.QHBoxLayout(self.vother)
        self.hboxlayout.setObjectName(_fromUtf8("hboxlayout"))
        self.gridLayout_6 = QtGui.QGridLayout()
        self.gridLayout_6.setObjectName(_fromUtf8("gridLayout_6"))
        self.vo_read = QtGui.QCheckBox(self.vother)
        self.vo_read.setObjectName(_fromUtf8("vo_read"))
        self.gridLayout_6.addWidget(self.vo_read, 0, 0, 1, 1)
        self.vo_write = QtGui.QCheckBox(self.vother)
        self.vo_write.setObjectName(_fromUtf8("vo_write"))
        self.gridLayout_6.addWidget(self.vo_write, 1, 0, 1, 1)
        self.vo_show = QtGui.QCheckBox(self.vother)
        self.vo_show.setObjectName(_fromUtf8("vo_show"))
        self.gridLayout_6.addWidget(self.vo_show, 2, 0, 1, 1)
        self.vo_rperm = QtGui.QCheckBox(self.vother)
        self.vo_rperm.setObjectName(_fromUtf8("vo_rperm"))
        self.gridLayout_6.addWidget(self.vo_rperm, 3, 0, 1, 1)
        self.vo_wperm = QtGui.QCheckBox(self.vother)
        self.vo_wperm.setObjectName(_fromUtf8("vo_wperm"))
        self.gridLayout_6.addWidget(self.vo_wperm, 4, 0, 1, 1)
        self.vo_utake = QtGui.QCheckBox(self.vother)
        self.vo_utake.setObjectName(_fromUtf8("vo_utake"))
        self.gridLayout_6.addWidget(self.vo_utake, 5, 0, 1, 1)
        self.vo_gtake = QtGui.QCheckBox(self.vother)
        self.vo_gtake.setObjectName(_fromUtf8("vo_gtake"))
        self.gridLayout_6.addWidget(self.vo_gtake, 6, 0, 1, 1)
        self.vo_ugive = QtGui.QCheckBox(self.vother)
        self.vo_ugive.setObjectName(_fromUtf8("vo_ugive"))
        self.gridLayout_6.addWidget(self.vo_ugive, 7, 0, 1, 1)
        self.vo_ggive = QtGui.QCheckBox(self.vother)
        self.vo_ggive.setObjectName(_fromUtf8("vo_ggive"))
        self.gridLayout_6.addWidget(self.vo_ggive, 8, 0, 1, 1)
        self.vo_del = QtGui.QCheckBox(self.vother)
        self.vo_del.setObjectName(_fromUtf8("vo_del"))
        self.gridLayout_6.addWidget(self.vo_del, 9, 0, 1, 1)
        self.hboxlayout.addLayout(self.gridLayout_6)
        self.permtab.addTab(self.vother, _fromUtf8(""))

        self.retranslateUi(userperms)
        self.permtab.setCurrentIndex(2)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), userperms.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), userperms.reject)
        QtCore.QMetaObject.connectSlotsByName(userperms)
        userperms.setTabOrder(self.servname, self.username)
        userperms.setTabOrder(self.username, self.groupname)
        userperms.setTabOrder(self.groupname, self.minpri)
        userperms.setTabOrder(self.minpri, self.defpri)
        userperms.setTabOrder(self.defpri, self.maxpri)
        userperms.setTabOrder(self.maxpri, self.maxll)
        userperms.setTabOrder(self.maxll, self.totll)
        userperms.setTabOrder(self.totll, self.speccll)
        userperms.setTabOrder(self.speccll, self.radminperm)
        userperms.setTabOrder(self.radminperm, self.wadminperm)
        userperms.setTabOrder(self.wadminperm, self.createperm)
        userperms.setTabOrder(self.createperm, self.chpermperm)
        userperms.setTabOrder(self.chpermperm, self.spcreateperm)
        userperms.setTabOrder(self.spcreateperm, self.or_ug_perm)
        userperms.setTabOrder(self.or_ug_perm, self.or_uo_perm)
        userperms.setTabOrder(self.or_uo_perm, self.or_go_perm)
        userperms.setTabOrder(self.or_go_perm, self.sstopperm)
        userperms.setTabOrder(self.sstopperm, self.permtab)
        userperms.setTabOrder(self.permtab, self.ju_read)
        userperms.setTabOrder(self.ju_read, self.ju_write)
        userperms.setTabOrder(self.ju_write, self.ju_show)
        userperms.setTabOrder(self.ju_show, self.ju_rperm)
        userperms.setTabOrder(self.ju_rperm, self.ju_wperm)
        userperms.setTabOrder(self.ju_wperm, self.ju_utake)
        userperms.setTabOrder(self.ju_utake, self.ju_gtake)
        userperms.setTabOrder(self.ju_gtake, self.ju_ugive)
        userperms.setTabOrder(self.ju_ugive, self.ju_ggive)
        userperms.setTabOrder(self.ju_ggive, self.ju_del)
        userperms.setTabOrder(self.ju_del, self.ju_kill)
        userperms.setTabOrder(self.ju_kill, self.jg_read)
        userperms.setTabOrder(self.jg_read, self.jg_write)
        userperms.setTabOrder(self.jg_write, self.jg_show)
        userperms.setTabOrder(self.jg_show, self.jg_rperm)
        userperms.setTabOrder(self.jg_rperm, self.jg_wperm)
        userperms.setTabOrder(self.jg_wperm, self.jg_utake)
        userperms.setTabOrder(self.jg_utake, self.jg_gtake)
        userperms.setTabOrder(self.jg_gtake, self.jg_ugive)
        userperms.setTabOrder(self.jg_ugive, self.jg_ggive)
        userperms.setTabOrder(self.jg_ggive, self.jg_del)
        userperms.setTabOrder(self.jg_del, self.jg_kill)
        userperms.setTabOrder(self.jg_kill, self.jo_read)
        userperms.setTabOrder(self.jo_read, self.jo_write)
        userperms.setTabOrder(self.jo_write, self.jo_show)
        userperms.setTabOrder(self.jo_show, self.jo_rperm)
        userperms.setTabOrder(self.jo_rperm, self.jo_wperm)
        userperms.setTabOrder(self.jo_wperm, self.jo_utake)
        userperms.setTabOrder(self.jo_utake, self.jo_gtake)
        userperms.setTabOrder(self.jo_gtake, self.jo_ugive)
        userperms.setTabOrder(self.jo_ugive, self.jo_ggive)
        userperms.setTabOrder(self.jo_ggive, self.jo_del)
        userperms.setTabOrder(self.jo_del, self.jo_kill)
        userperms.setTabOrder(self.jo_kill, self.vu_read)
        userperms.setTabOrder(self.vu_read, self.vu_write)
        userperms.setTabOrder(self.vu_write, self.vu_show)
        userperms.setTabOrder(self.vu_show, self.vu_rperm)
        userperms.setTabOrder(self.vu_rperm, self.vu_wperm)
        userperms.setTabOrder(self.vu_wperm, self.vu_utake)
        userperms.setTabOrder(self.vu_utake, self.vu_gtake)
        userperms.setTabOrder(self.vu_gtake, self.vu_ugive)
        userperms.setTabOrder(self.vu_ugive, self.vu_ggive)
        userperms.setTabOrder(self.vu_ggive, self.vu_del)
        userperms.setTabOrder(self.vu_del, self.vg_read)
        userperms.setTabOrder(self.vg_read, self.vg_write)
        userperms.setTabOrder(self.vg_write, self.vg_show)
        userperms.setTabOrder(self.vg_show, self.vg_rperm)
        userperms.setTabOrder(self.vg_rperm, self.vg_wperm)
        userperms.setTabOrder(self.vg_wperm, self.vg_utake)
        userperms.setTabOrder(self.vg_utake, self.vg_gtake)
        userperms.setTabOrder(self.vg_gtake, self.vg_ugive)
        userperms.setTabOrder(self.vg_ugive, self.vg_ggive)
        userperms.setTabOrder(self.vg_ggive, self.vg_del)
        userperms.setTabOrder(self.vg_del, self.vo_read)
        userperms.setTabOrder(self.vo_read, self.vo_write)
        userperms.setTabOrder(self.vo_write, self.vo_show)
        userperms.setTabOrder(self.vo_show, self.vo_rperm)
        userperms.setTabOrder(self.vo_rperm, self.vo_wperm)
        userperms.setTabOrder(self.vo_wperm, self.vo_utake)
        userperms.setTabOrder(self.vo_utake, self.vo_gtake)
        userperms.setTabOrder(self.vo_gtake, self.vo_ugive)
        userperms.setTabOrder(self.vo_ugive, self.vo_ggive)
        userperms.setTabOrder(self.vo_ggive, self.vo_del)
        userperms.setTabOrder(self.vo_del, self.buttonBox)

    def retranslateUi(self, userperms):
        userperms.setWindowTitle(QtGui.QApplication.translate("userperms", "User permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("userperms", "User permissions on server", None, QtGui.QApplication.UnicodeUTF8))
        self.servname.setToolTip(QtGui.QApplication.translate("userperms", "This is the server to which the permissions apply", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("userperms", "User Name", None, QtGui.QApplication.UnicodeUTF8))
        self.username.setToolTip(QtGui.QApplication.translate("userperms", "This is the user name on the server", None, QtGui.QApplication.UnicodeUTF8))
        self.radminperm.setToolTip(QtGui.QApplication.translate("userperms", "User can read admin file", None, QtGui.QApplication.UnicodeUTF8))
        self.radminperm.setText(QtGui.QApplication.translate("userperms", "Read admin file", None, QtGui.QApplication.UnicodeUTF8))
        self.wadminperm.setToolTip(QtGui.QApplication.translate("userperms", "User can edit admin file of permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.wadminperm.setText(QtGui.QApplication.translate("userperms", "Write admin file", None, QtGui.QApplication.UnicodeUTF8))
        self.createperm.setToolTip(QtGui.QApplication.translate("userperms", "User can create objects (jobs and variables)", None, QtGui.QApplication.UnicodeUTF8))
        self.createperm.setText(QtGui.QApplication.translate("userperms", "Create things", None, QtGui.QApplication.UnicodeUTF8))
        self.chpermperm.setToolTip(QtGui.QApplication.translate("userperms", "User can adjust default priority and permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.chpermperm.setText(QtGui.QApplication.translate("userperms", "Change default prio/perms", None, QtGui.QApplication.UnicodeUTF8))
        self.spcreateperm.setToolTip(QtGui.QApplication.translate("userperms", "User can create command interpreters", None, QtGui.QApplication.UnicodeUTF8))
        self.spcreateperm.setText(QtGui.QApplication.translate("userperms", "Special Create", None, QtGui.QApplication.UnicodeUTF8))
        self.or_ug_perm.setToolTip(QtGui.QApplication.translate("userperms", "Combine user and group permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.or_ug_perm.setText(QtGui.QApplication.translate("userperms", "OR User/Group perms", None, QtGui.QApplication.UnicodeUTF8))
        self.or_uo_perm.setToolTip(QtGui.QApplication.translate("userperms", "Combine user and other permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.or_uo_perm.setText(QtGui.QApplication.translate("userperms", "OR User/Other perms", None, QtGui.QApplication.UnicodeUTF8))
        self.or_go_perm.setToolTip(QtGui.QApplication.translate("userperms", "Combine group and other permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.or_go_perm.setText(QtGui.QApplication.translate("userperms", "OR Group/Other perms", None, QtGui.QApplication.UnicodeUTF8))
        self.sstopperm.setToolTip(QtGui.QApplication.translate("userperms", "User can stop the scheduler", None, QtGui.QApplication.UnicodeUTF8))
        self.sstopperm.setText(QtGui.QApplication.translate("userperms", "Stop Scheduler", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("userperms", "Min Pri", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("userperms", "Def Pri", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("userperms", "Max Pri", None, QtGui.QApplication.UnicodeUTF8))
        self.minpri.setToolTip(QtGui.QApplication.translate("userperms", "This is the minimum allowed priority", None, QtGui.QApplication.UnicodeUTF8))
        self.defpri.setToolTip(QtGui.QApplication.translate("userperms", "This is the default priority", None, QtGui.QApplication.UnicodeUTF8))
        self.maxpri.setToolTip(QtGui.QApplication.translate("userperms", "This is the maximum priority", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("userperms", "Group Name", None, QtGui.QApplication.UnicodeUTF8))
        self.groupname.setToolTip(QtGui.QApplication.translate("userperms", "This is the group name on the server", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("userperms", "Spec C LL", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("userperms", "Tot LL", None, QtGui.QApplication.UnicodeUTF8))
        self.maxll.setToolTip(QtGui.QApplication.translate("userperms", "This is the maximum load level for any one job", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("userperms", "Max LL", None, QtGui.QApplication.UnicodeUTF8))
        self.speccll.setToolTip(QtGui.QApplication.translate("userperms", "This is the special create load level (if creating command interpreters)", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("userperms", "Default permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_read.setToolTip(QtGui.QApplication.translate("userperms", "User can read details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_read.setText(QtGui.QApplication.translate("userperms", "Read Job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_write.setToolTip(QtGui.QApplication.translate("userperms", "User can update details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_write.setText(QtGui.QApplication.translate("userperms", "Write job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_show.setToolTip(QtGui.QApplication.translate("userperms", "User can see job exists", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_show.setText(QtGui.QApplication.translate("userperms", "Reveal job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_rperm.setToolTip(QtGui.QApplication.translate("userperms", "User can read job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_wperm.setToolTip(QtGui.QApplication.translate("userperms", "User can update job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_utake.setToolTip(QtGui.QApplication.translate("userperms", "User can acquire job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_gtake.setToolTip(QtGui.QApplication.translate("userperms", "User can acquire job for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_ugive.setToolTip(QtGui.QApplication.translate("userperms", "User can give away job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_del.setToolTip(QtGui.QApplication.translate("userperms", "User can delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_del.setText(QtGui.QApplication.translate("userperms", "Delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_kill.setToolTip(QtGui.QApplication.translate("userperms", "User can kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_kill.setText(QtGui.QApplication.translate("userperms", "Kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_ggive.setToolTip(QtGui.QApplication.translate("userperms", "User can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.juser), QtGui.QApplication.translate("userperms", "Job-user", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_read.setToolTip(QtGui.QApplication.translate("userperms", "Group can read details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_read.setText(QtGui.QApplication.translate("userperms", "Read Job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_write.setToolTip(QtGui.QApplication.translate("userperms", "Group can update details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_write.setText(QtGui.QApplication.translate("userperms", "Write job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_show.setToolTip(QtGui.QApplication.translate("userperms", "Group can see job exists", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_show.setText(QtGui.QApplication.translate("userperms", "Reveal job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_rperm.setToolTip(QtGui.QApplication.translate("userperms", "Group can read job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_wperm.setToolTip(QtGui.QApplication.translate("userperms", "Group can update job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_utake.setToolTip(QtGui.QApplication.translate("userperms", "Group can acquire job for user", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_gtake.setToolTip(QtGui.QApplication.translate("userperms", "Group can acquire job for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_ugive.setToolTip(QtGui.QApplication.translate("userperms", "Group can give away job owner", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_del.setToolTip(QtGui.QApplication.translate("userperms", "Group can delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_del.setText(QtGui.QApplication.translate("userperms", "Delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_kill.setToolTip(QtGui.QApplication.translate("userperms", "Group can kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_kill.setText(QtGui.QApplication.translate("userperms", "Kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_ggive.setToolTip(QtGui.QApplication.translate("userperms", "Group can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.jgroup), QtGui.QApplication.translate("userperms", "Job-group", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_read.setToolTip(QtGui.QApplication.translate("userperms", "Others can read details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_read.setText(QtGui.QApplication.translate("userperms", "Read Job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_write.setToolTip(QtGui.QApplication.translate("userperms", "Others can update details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_write.setText(QtGui.QApplication.translate("userperms", "Write job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_show.setToolTip(QtGui.QApplication.translate("userperms", "Others can see job exists", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_show.setText(QtGui.QApplication.translate("userperms", "Reveal job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_rperm.setToolTip(QtGui.QApplication.translate("userperms", "Others can read job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_wperm.setToolTip(QtGui.QApplication.translate("userperms", "Others can update job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_utake.setToolTip(QtGui.QApplication.translate("userperms", "Others can acquire job for owner", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_gtake.setToolTip(QtGui.QApplication.translate("userperms", "Others can acquire job for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_ugive.setToolTip(QtGui.QApplication.translate("userperms", "Others can give away job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_del.setToolTip(QtGui.QApplication.translate("userperms", "Others can delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_del.setText(QtGui.QApplication.translate("userperms", "Delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_kill.setToolTip(QtGui.QApplication.translate("userperms", "Others can kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_kill.setText(QtGui.QApplication.translate("userperms", "Kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_ggive.setToolTip(QtGui.QApplication.translate("userperms", "Others can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.jother), QtGui.QApplication.translate("userperms", "Job-other", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_read.setToolTip(QtGui.QApplication.translate("userperms", "User can read details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_read.setText(QtGui.QApplication.translate("userperms", "Read variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_write.setToolTip(QtGui.QApplication.translate("userperms", "User can update details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_write.setText(QtGui.QApplication.translate("userperms", "Write variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_show.setToolTip(QtGui.QApplication.translate("userperms", "User can see variable exists", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_show.setText(QtGui.QApplication.translate("userperms", "Reveal variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_rperm.setToolTip(QtGui.QApplication.translate("userperms", "User can read variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_wperm.setToolTip(QtGui.QApplication.translate("userperms", "User can update variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_utake.setToolTip(QtGui.QApplication.translate("userperms", "User can acquire variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_gtake.setToolTip(QtGui.QApplication.translate("userperms", "User can acquire variable for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_ugive.setToolTip(QtGui.QApplication.translate("userperms", "User can give away variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_del.setToolTip(QtGui.QApplication.translate("userperms", "User can delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_del.setText(QtGui.QApplication.translate("userperms", "Delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_ggive.setToolTip(QtGui.QApplication.translate("userperms", "User can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.vuser), QtGui.QApplication.translate("userperms", "Var-user", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_read.setToolTip(QtGui.QApplication.translate("userperms", "Group can read details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_read.setText(QtGui.QApplication.translate("userperms", "Read variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_write.setToolTip(QtGui.QApplication.translate("userperms", "Group can update details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_write.setText(QtGui.QApplication.translate("userperms", "Write variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_show.setToolTip(QtGui.QApplication.translate("userperms", "Group can see variable exists", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_show.setText(QtGui.QApplication.translate("userperms", "Reveal variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_rperm.setToolTip(QtGui.QApplication.translate("userperms", "Group can read variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_wperm.setToolTip(QtGui.QApplication.translate("userperms", "Group can update variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_utake.setToolTip(QtGui.QApplication.translate("userperms", "Group can acquire variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_gtake.setToolTip(QtGui.QApplication.translate("userperms", "Group can acquire variable for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_ugive.setToolTip(QtGui.QApplication.translate("userperms", "Group can give away variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_ggive.setToolTip(QtGui.QApplication.translate("userperms", "Group can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_del.setToolTip(QtGui.QApplication.translate("userperms", "Group can delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_del.setText(QtGui.QApplication.translate("userperms", "Delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.vgroup), QtGui.QApplication.translate("userperms", "Var-group", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_read.setToolTip(QtGui.QApplication.translate("userperms", "Others can read details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_read.setText(QtGui.QApplication.translate("userperms", "Read variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_write.setToolTip(QtGui.QApplication.translate("userperms", "Others can update details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_write.setText(QtGui.QApplication.translate("userperms", "Write variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_show.setToolTip(QtGui.QApplication.translate("userperms", "Others can see variable exists", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_show.setText(QtGui.QApplication.translate("userperms", "Reveal variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_rperm.setToolTip(QtGui.QApplication.translate("userperms", "Others can read variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_wperm.setToolTip(QtGui.QApplication.translate("userperms", "Others can update variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_utake.setToolTip(QtGui.QApplication.translate("userperms", "Others can acquire variable for user", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_gtake.setToolTip(QtGui.QApplication.translate("userperms", "Others can acquire variable for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_ugive.setToolTip(QtGui.QApplication.translate("userperms", "Others can give away variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_ggive.setToolTip(QtGui.QApplication.translate("userperms", "Others can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_del.setToolTip(QtGui.QApplication.translate("userperms", "Others can delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_del.setText(QtGui.QApplication.translate("userperms", "Delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.vother), QtGui.QApplication.translate("userperms", "Var-other", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'hostdlg.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_hostdlg(object):
    def setupUi(self, hostdlg):
        hostdlg.setObjectName(_fromUtf8("hostdlg"))
        hostdlg.resize(400, 237)
        self.buttonBox = QtGui.QDialogButtonBox(hostdlg)
        self.buttonBox.setGeometry(QtCore.QRect(40, 190, 341, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.layoutWidget = QtGui.QWidget(hostdlg)
        self.layoutWidget.setGeometry(QtCore.QRect(20, 10, 361, 121))
        self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
        self.gridLayout = QtGui.QGridLayout(self.layoutWidget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.label = QtGui.QLabel(self.layoutWidget)
        self.label.setObjectName(_fromUtf8("label"))
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.hostName = QtGui.QLineEdit(self.layoutWidget)
        self.hostName.setObjectName(_fromUtf8("hostName"))
        self.gridLayout.addWidget(self.hostName, 0, 1, 1, 2)
        self.label_2 = QtGui.QLabel(self.layoutWidget)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.aliasName = QtGui.QLineEdit(self.layoutWidget)
        self.aliasName.setObjectName(_fromUtf8("aliasName"))
        self.gridLayout.addWidget(self.aliasName, 1, 1, 1, 2)
        self.autoconn = QtGui.QCheckBox(hostdlg)
        self.autoconn.setGeometry(QtCore.QRect(20, 150, 191, 22))
        self.autoconn.setObjectName(_fromUtf8("autoconn"))
        self.label.setBuddy(self.hostName)
        self.label_2.setBuddy(self.aliasName)

        self.retranslateUi(hostdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), hostdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), hostdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(hostdlg)
        hostdlg.setTabOrder(self.hostName, self.aliasName)
        hostdlg.setTabOrder(self.aliasName, self.autoconn)
        hostdlg.setTabOrder(self.autoconn, self.buttonBox)

    def retranslateUi(self, hostdlg):
        hostdlg.setWindowTitle(QtGui.QApplication.translate("hostdlg", "Host name", None, QtGui.QApplication.UnicodeUTF8))
        self.buttonBox.setToolTip(QtGui.QApplication.translate("hostdlg", "Attempt to connect to this server at startup", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("hostdlg", "&Host", None, QtGui.QApplication.UnicodeUTF8))
        self.hostName.setToolTip(QtGui.QApplication.translate("hostdlg", "This is the host name to connect to or an IP address", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("hostdlg", "&Alias", None, QtGui.QApplication.UnicodeUTF8))
        self.aliasName.setToolTip(QtGui.QApplication.translate("hostdlg", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Bitstream Vera Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Shorter alias for host name - <span style=\" font-weight:600;\">must</span> have it if host is IP</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.autoconn.setText(QtGui.QApplication.translate("hostdlg", "Try to connect at startup", None, QtGui.QApplication.UnicodeUTF8))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'createvar.ui'
#
# Created: Sat Nov 24 18:45:50 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_crevardlg(object):
    def setupUi(self, crevardlg):
        crevardlg.setObjectName(_fromUtf8("crevardlg"))
        crevardlg.resize(561, 338)
        self.buttonBox = QtGui.QDialogButtonBox(crevardlg)
        self.buttonBox.setGeometry(QtCore.QRect(340, 290, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(crevardlg)
        self.label.setGeometry(QtCore.QRect(50, 70, 51, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.varname = QtGui.QLineEdit(crevardlg)
        self.varname.setGeometry(QtCore.QRect(150, 70, 221, 27))
        self.varname.setMaxLength(19)
        self.varname.setObjectName(_fromUtf8("varname"))
        self.label_2 = QtGui.QLabel(crevardlg)
        self.label_2.setGeometry(QtCore.QRect(50, 110, 91, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.comment = QtGui.QLineEdit(crevardlg)
        self.comment.setGeometry(QtCore.QRect(150, 110, 381, 27))
        self.comment.setMaxLength(41)
        self.comment.setObjectName(_fromUtf8("comment"))
        self.label_3 = QtGui.QLabel(crevardlg)
        self.label_3.setGeometry(QtCore.QRect(50, 150, 51, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.intval = QtGui.QSpinBox(crevardlg)
        self.intval.setGeometry(QtCore.QRect(150, 150, 101, 27))
        self.intval.setMinimum(-10000000)
        self.intval.setMaximum(10000000)
        self.intval.setObjectName(_fromUtf8("intval"))
        self.istext = QtGui.QCheckBox(crevardlg)
        self.istext.setGeometry(QtCore.QRect(310, 150, 131, 22))
        self.istext.setObjectName(_fromUtf8("istext"))
        self.textval = QtGui.QLineEdit(crevardlg)
        self.textval.setEnabled(False)
        self.textval.setGeometry(QtCore.QRect(150, 190, 347, 28))
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval.setFont(font)
        self.textval.setMaxLength(49)
        self.textval.setObjectName(_fromUtf8("textval"))
        self.label_4 = QtGui.QLabel(crevardlg)
        self.label_4.setGeometry(QtCore.QRect(50, 200, 71, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.exporttype = QtGui.QComboBox(crevardlg)
        self.exporttype.setGeometry(QtCore.QRect(50, 250, 191, 27))
        self.exporttype.setObjectName(_fromUtf8("exporttype"))
        self.exporttype.addItem(_fromUtf8(""))
        self.exporttype.addItem(_fromUtf8(""))
        self.exporttype.addItem(_fromUtf8(""))
        self.label_5 = QtGui.QLabel(crevardlg)
        self.label_5.setGeometry(QtCore.QRect(50, 30, 111, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.crehost = QtGui.QComboBox(crevardlg)
        self.crehost.setGeometry(QtCore.QRect(170, 20, 181, 27))
        self.crehost.setObjectName(_fromUtf8("crehost"))

        self.retranslateUi(crevardlg)
        self.exporttype.setCurrentIndex(1)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), crevardlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), crevardlg.reject)
        QtCore.QMetaObject.connectSlotsByName(crevardlg)
        crevardlg.setTabOrder(self.crehost, self.varname)
        crevardlg.setTabOrder(self.varname, self.comment)
        crevardlg.setTabOrder(self.comment, self.intval)
        crevardlg.setTabOrder(self.intval, self.istext)
        crevardlg.setTabOrder(self.istext, self.textval)
        crevardlg.setTabOrder(self.textval, self.exporttype)
        crevardlg.setTabOrder(self.exporttype, self.buttonBox)

    def retranslateUi(self, crevardlg):
        crevardlg.setWindowTitle(QtGui.QApplication.translate("crevardlg", "Create Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("crevardlg", "Name", None, QtGui.QApplication.UnicodeUTF8))
        self.varname.setToolTip(QtGui.QApplication.translate("crevardlg", "This is the name of the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("crevardlg", "Description", None, QtGui.QApplication.UnicodeUTF8))
        self.comment.setToolTip(QtGui.QApplication.translate("crevardlg", "This is a description or comment about the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("crevardlg", "Value", None, QtGui.QApplication.UnicodeUTF8))
        self.intval.setToolTip(QtGui.QApplication.translate("crevardlg", "This is the value for the variable if an integer", None, QtGui.QApplication.UnicodeUTF8))
        self.istext.setToolTip(QtGui.QApplication.translate("crevardlg", "Indicates variable has text value", None, QtGui.QApplication.UnicodeUTF8))
        self.istext.setText(QtGui.QApplication.translate("crevardlg", "Has Text Value", None, QtGui.QApplication.UnicodeUTF8))
        self.textval.setToolTip(QtGui.QApplication.translate("crevardlg", "Give the text value to be used if variable has to have this\n"
"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("crevardlg", "Text value", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setToolTip(QtGui.QApplication.translate("crevardlg", "Set export marker on variable\n"
"\n"
"Local only means it\'s only visible and usable on the server in question.\n"
"\n"
"Exported means it can be visible on all hosts\n"
"\n"
"Clustered (this is going to be phased out) means that the version on the\n"
"server is always used.", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(0, QtGui.QApplication.translate("crevardlg", "Local Only", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(1, QtGui.QApplication.translate("crevardlg", "Exported", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(2, QtGui.QApplication.translate("crevardlg", "Clustered", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("crevardlg", "Create on host", None, QtGui.QApplication.UnicodeUTF8))
        self.crehost.setToolTip(QtGui.QApplication.translate("crevardlg", "This is the server on which the variable is created", None, QtGui.QApplication.UnicodeUTF8))

